summaryrefslogtreecommitdiff
path: root/framework/I18N/TDateFormat.php
diff options
context:
space:
mode:
authorFabio Bas <ctrlaltca@gmail.com>2015-01-25 20:04:57 +0100
committerFabio Bas <ctrlaltca@gmail.com>2015-01-25 20:04:57 +0100
commite4999b25052d1ad9400a0f9fd5289a49eea1bddc (patch)
tree50e9b819fc3326cf08e882b648f8dafc8fec3fa4 /framework/I18N/TDateFormat.php
parent5230f8f8a86fc1ae5d90f8c74ae65c93e197502b (diff)
More namespace changes
Changed version to 3.2.99; Attempt at fixing autoloading fixed enough namespaces to have some demos running
Diffstat (limited to 'framework/I18N/TDateFormat.php')
-rw-r--r--framework/I18N/TDateFormat.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/framework/I18N/TDateFormat.php b/framework/I18N/TDateFormat.php
index 638930fe..eedabfb4 100644
--- a/framework/I18N/TDateFormat.php
+++ b/framework/I18N/TDateFormat.php
@@ -59,7 +59,7 @@ Prado::using('System.I18N.TI18NControl');
* @author Xiang Wei Zhuo <weizhuo[at]gmail[dot]com>
* @package Prado\I18N
*/
-class TDateFormat extends TI18NControl implements IDataRenderer
+class TDateFormat extends TI18NControl implements \Prado\IDataRenderer
{
/**
* Default DateFormat, set to the application culture.
@@ -186,7 +186,7 @@ class TDateFormat extends TI18NControl implements IDataRenderer
/**
* Get the date-time value for this control.
* This method is required by {@link IDataRenderer}.
* It is the same as {@link getValue()}.
* @return string date time value.
* @see getValue
@@ -199,7 +199,7 @@ class TDateFormat extends TI18NControl implements IDataRenderer
/**
* Set the date-time value for this control.
* This method is required by {@link IDataRenderer}.
* It is the same as {@link setValue()}.
* @param string the date-time value.
* @see setValue
@@ -186,7 +186,7 @@ class TDateFormat extends TI18NControl implements IDataRenderer
/**
* Get the date-time value for this control.
- * This method is required by {@link IDataRenderer}.
+ * This method is required by {@link \Prado\IDataRenderer}.
* It is the same as {@link getValue()}.
* @return string date time value.
@@ -199,7 +199,7 @@ class TDateFormat extends TI18NControl implements IDataRenderer
/**
* Set the date-time value for this control.
- * This method is required by {@link IDataRenderer}.
+ * This method is required by {@link \Prado\IDataRenderer}.
* It is the same as {@link setValue()}.
* @param string the date-time value.